@@ -1,6 +1,6 @@
 package App::ansiecho;
 
-our $VERSION = "0.01";
+our $VERSION = "0.02";
 
 use v5.14;
 use warnings;
@@ -23,7 +23,7 @@ has debug      => ( is => 'ro' );
 has verbose    => ( is => 'ro', default => 1 );
 has no_newline => ( is => 'ro' );
 has join       => ( is => 'ro' );
-has escape     => ( is => 'ro' );
+has escape     => ( is => 'ro', default => 1 );
 has rgb24      => ( is => 'ro' );
 has separate   => ( is => 'rw', default => " " );
 
@@ -79,19 +79,40 @@ sub retrieve {
     my $in = $app->params;
     my @out;
     my @pending;
+    my(@style, @effect);
 
     my $append = sub {
 	push @out, join '', splice(@pending), @_;
     };
     while (@$in) {
 	my $arg = shift @$in;
+
+	# -c, -C
+	if ($arg =~ /^-([cC])(.+)?$/) {
+	    my $target = $1 eq 'c' ? \@effect : \@style;
+	    my($color) = defined $2 ? safe_backslash($2) : $app->retrieve(1);
+	    unshift @$target, [ \&colorize, $color ];
+	    next;
+	}
+	# -F
+	if ($arg =~ /^-(F)(.+)?$/) {
+	    my($format) = defined $2 ? safe_backslash($2) : $app->retrieve(1);
+	    unshift @style, [ \&ansi_sprintf, $format ];
+	    next;
+	}
+	# -E
+	if ($arg =~ /^-E$/) {
+	    @style = ();
+	    next;
+	}
+
 	#
 	# -r     : raw data
 	# -s, -z : ansi sequence
 	#
 	if ($arg =~ /^-([szr])(.+)?$/) {
 	    my $opt = $1;
-	    my $text = $2 || shift(@$in) // die "Not enough argument.\n";
+	    my $text = $2 // shift(@$in) // die "Not enough argument.\n";
 	    my $data = $opt eq 'r' ? safe_backslash($text) : ansi_code($text);
 	    if (@out == 0 or $opt eq 's') {
 		push @pending, $data;
@@ -100,41 +121,36 @@ sub retrieve {
 	    }
 	    next;
 	}
-	#
-	# -c : color
-	#
-	if ($arg =~ /^-c((?![\/\^~;#])\pP)?+(.+)?$/) {
-	    my($delim, $param) = ($1, $2);
-	    my($color, $string);
-	    if ($delim and $param and $param =~ $delim) {
-		($color, $string) = split $delim, $param, 2;
-	    }
-	    else {
-		($color) = defined $param ? $param : $app->retrieve(1);
-		($string) = $app->retrieve(1);
-	    }
-	    $string = safe_backslash($string) if $app->escape;
-	    $append->(colorize($color, $string));
-	}
+
 	#
 	# -f : format
 	#
-	elsif ($arg =~ /^-f(.+)?$/) {
-	    my($format) = defined $1 ? $1 : $app->retrieve(1);
-	    $format = safe_backslash($format);
+	if ($arg =~ /^-f(.+)?$/) {
+	    my($format) = defined $1 ? safe_backslash($1) : $app->retrieve(1);
 	    my $n = sum map {
 		{ '%' => 0, '*' => 2, '*.*' => 3 }->{$_} // 1
 	    } $format =~ /(?| %(%) | %[-+ #0]*+(\*(?:\.\*)?|.) )/xg;
-	    $append->(ansi_sprintf($format, $app->retrieve($n)));
+	    $arg = ansi_sprintf($format, $app->retrieve($n));
 	}
 	#
-	# string argument
+	# normal string argument
 	#
 	else {
-	    $arg = safe_backslash($arg) if $app->escape;
-	    $append->($arg);
+	    if ($app->escape) {
+		$arg = safe_backslash($arg);
+	    }
 	}
 
+	#
+	# apply @effect and @style
+	#
+	for (splice(@effect), @style) {
+	    my($func, @opts) = @$_;
+	    $arg = $func->(@opts, $arg);
+	}
+
+	$append->($arg);
+
 	if ($count) {
 	    my $out = @out + !!@pending;
 	    die "Unexpected behavior.\n" if $out > $count;
